@@ -13,6 +13,7 @@ package MBX::Alien::FLTK::Platform::Windows;
 
     sub configure {
         my ($self) = @_;
+        $self->quiet(1);
         $self->SUPER::configure();    # Get basic config data
         print "Gathering Windows specific configuration data...\n";
         $self->notes(ldflags => $self->notes('ldflags')
@@ -33,8 +34,13 @@ package MBX::Alien::FLTK::Platform::Windows;
             print 'Checking for OpenGL... ';
             my $GL_LIB = '';
             $self->notes('config')->{'HAVE_GL'} = 0;
-            if (!$self->assert_lib(lib => 'opengl32', header => 'GL/gl.h')) {
-                print "no\n";
+            if (!$self->assert_lib({lib => 'opengl32', header => 'GL/gl.h'}))
+            {   print "no\n";
+                push @{$self->notes('errors')},
+                    {stage   => 'configure',
+                     fatal   => 0,
+                     message => 'OpenGL libs were not found'
+                    };
             }
             else {
                 $self->notes('config')->{'HAVE_GL'} = 1;
@@ -44,7 +50,8 @@ package MBX::Alien::FLTK::Platform::Windows;
                 #
                 print 'Checking for GL/glu.h... ';
                 $self->notes('config')->{'HAVE_GL_GLU_H'} = 0;
-                if (!$self->assert_lib(lib => 'glu32', header => 'GL/glu.h'))
+                if (!$self->assert_lib({lib => 'glu32', header => 'GL/glu.h'})
+                    )
                 {   print "no\n";
                 }
                 else {
@@ -55,6 +62,7 @@ package MBX::Alien::FLTK::Platform::Windows;
             }
             $self->notes(GL => $GL_LIB);
         }
+        $self->quiet(0);
         return 1;
     }
     1;
@@ -82,6 +90,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: Windows.pm 19d9998 2009-09-11 18:15:03Z sanko@cpan.org $
+=for git $Id: Windows.pm 347de4a 2009-10-09 00:59:57Z sanko@cpan.org $
 
 =cut
